@@ -1,5 +1,7 @@
 from ._python_calamine import (  # noqa: F401
     CalamineError,
+    CalamineReader,
+    CalamineSheet,
     get_sheet_data,
     get_sheet_names,
 )
